# Build configuration

%ifarch %{arm} aarch64 %{ix86}
%define build_docs 0
%else
%define build_docs 1
%endif

# Versioning

%define qtmajor 5
%define qtminor 15
%define qtsubminor 16
%define qtversion %{qtmajor}.%{qtminor}.%{qtsubminor}

%define rel 1

%define snapshot 0

%if 0%{?snapshot}
%define pre rc
%endif

%define qttarballdir qtmultimedia-everywhere-opensource-src-%{qtversion}%{?pre:-%{pre}}

# Library names

%define libqt5multimedia           %mklibname qt%{qtmajor}multimedia %{qtmajor}
%define libqt5multimedia_d         %mklibname qt%{qtmajor}multimedia -d

%define libqt5multimediawidgets    %mklibname qt%{qtmajor}multimediawidgets %{qtmajor}
%define libqt5multimediawidgets_d  %mklibname qt%{qtmajor}multimediawidgets -d

%define libqt5multimediagsttools   %mklibname qt%{qtmajor}multimediagsttools %{qtmajor}
%define libqt5multimediagsttools_d %mklibname qt%{qtmajor}multimediagsttools -d

%define libqtmultimediaquick       %mklibname qt%{qtmajor}multimediaquick %{qtmajor}
%define libqtmultimediaquick_d     %mklibname qt%{qtmajor}multimediaquick -d

Name:           qtmultimedia5
Version:        %{qtversion}
Release:        %mkrel %{rel}
Summary:        Qt%{qtmajor} Multimedia component
Group:          Development/KDE and Qt
License:        LGPLv2 with exceptions or GPLv3 with exceptions and GFDL
URL:            https://www.qt.io/
Source0:        https://download.qt.io/official_releases/qt/%{qtmajor}.%{qtminor}/%{version}/submodules/%{qttarballdir}.tar.xz

# Upstream patches
# https://community.kde.org/Qt5PatchCollection
## repo: https://invent.kde.org/qt/qt/qtmultimedia
## branch: kde/5.15
## git format-patch v5.15.16-lts-lgpl
Patch0001:      0001-Pass-explicit-GL-api-when-initializing-GStreamer-bac.patch
Patch0002:      0002-Drop-obsolete-QtOpengl-dependency.patch

BuildRequires:  qtbase5-devel = %{version}
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(openal)

BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-app-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-pbutils-1.0)
BuildRequires:  pkgconfig(gstreamer-video-1.0)
BuildRequires:  pkgconfig(gstreamer-bad-audio-1.0)

BuildRequires:  pkgconfig(libpulse)
BuildRequires:  pkgconfig(libpulse-mainloop-glib)
BuildRequires:  pkgconfig(alsa)

BuildRequires:  pkgconfig(Qt5Qml) = %{version}
BuildRequires:  pkgconfig(Qt5Quick) = %{version}

Provides:       qt%{qtmajor}-qtmultimedia = %{version}-%{release}

#Branch Patchs

#Trunk Patchs

#Patch from Mageia

#Patch from Fedora
Patch100000:    qt5-qtmultimedia-gcc11.patch

%description
Qt%{qtmajor} Multimedia component.

%files
%_qt5_plugindir/audio/*.so
%_qt5_plugindir/mediaservice/*.so
%_qt5_plugindir/playlistformats/libqtmultimedia_m3u.so
%_qt5_qml/QtAudioEngine
%_qt5_qml/QtMultimedia

#------------------------------------------------------------------------------

%if %{build_docs}
%package doc
Summary:        QtMultimedia%{qtmajor} APIs and tools docs
Group:          Documentation
BuildArch:      noarch
BuildRequires:  qttools5
# This one is required to build QCH-format documentation
# for APIs and tools in this package set
BuildRequires:  qttools5-assistant
Recommends:     qttools5-assistant

%description doc
Documentation for APIs and tools in QtMultimedia%{qtmajor} package for use with
Qt Assistant.

%files doc
%{_qt5_docdir}/qtmultimedia.qch
%{_qt5_docdir}/qtmultimedia/
%endif

#------------------------------------------------------------------------------

%package -n %{libqt5multimedia}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries

%description -n %{libqt5multimedia}
Qt%{qtmajor} Lib.

%files -n %{libqt5multimedia}
%{_qt5_libdir}/libQt5Multimedia.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqt5multimedia_d}
Summary:        Devel files needed to build apps based on QtMultimedia
Group:          Development/KDE and Qt
Requires:       %{libqt5multimedia} = %{version}
Requires:       %{name} = %{version}
Provides:       libqtmultimedia5-devel = %{version}
Provides:       libqt5multimedia-devel = %{version}
Provides:       qtmultimedia5-devel = %{version}
Provides:       qt5multimedia-devel = %{version}

Provides:       libqtmultimedia5-private-devel = %{version}
Provides:       libqt5multimedia-private-devel = %{version}
Provides:       qtmultimedia5-private-devel = %{version}
Provides:       qt5multimedia-private-devel = %{version}

%description -n %{libqt5multimedia_d}
Devel files needed to build apps based on QtMultimedia.

%files -n %{libqt5multimedia_d}
%{_qt5_libdir}/cmake/Qt5Multimedia
%{_qt5_includedir}/QtMultimedia/
%{_qt5_libdir}/libQt5Multimedia.so
%{_qt5_libdir}/libQt5Multimedia.prl
%{_qt5_libdir}/pkgconfig/Qt5Multimedia.pc
%{_qt5_examplesdir}/multimedia
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimedia.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimedia_private.pri

#------------------------------------------------------------------------------

%package -n %{libqt5multimediawidgets}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqt5multimediawidgets}
Qt%{qtmajor} Lib.

%files -n %{libqt5multimediawidgets}
%{_qt5_libdir}/libQt5MultimediaWidgets.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqt5multimediawidgets_d}
Summary:        Devel files needed to build apps based on QtMultimediaWidget
Group:          Development/KDE and Qt
Requires:       %{libqt5multimediawidgets} = %{version}
Provides:       libqtmultimediawidgets5-devel = %{version}
Provides:       libqt5multimediawidgets-devel = %{version}
Provides:       qtmultimediawidgets5-devel = %{version}
Provides:       qt5multimediawidgets-devel = %{version}

Provides:       libqtmultimediawidgets5-private-devel = %{version}
Provides:       libqt5multimediawidgets-private-devel = %{version}
Provides:       qtmultimediawidgets5-private-devel = %{version}
Provides:       qt5multimediawidgets-private-devel = %{version}

%description -n %{libqt5multimediawidgets_d}
Devel files needed to build apps based on QtMultimediaWidget.

%files -n %{libqt5multimediawidgets_d}
%{_qt5_libdir}/cmake/Qt5MultimediaWidgets
%{_qt5_includedir}/QtMultimediaWidgets/
%{_qt5_libdir}/libQt5MultimediaWidgets.so
%{_qt5_libdir}/libQt5MultimediaWidgets.prl
%{_qt5_libdir}/pkgconfig/Qt5MultimediaWidgets.pc
%{_qt5_examplesdir}/multimediawidgets
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimediawidgets.pri
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimediawidgets_private.pri

#------------------------------------------------------------------------------

%package -n %{libqt5multimediagsttools}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries

%description -n %{libqt5multimediagsttools}
Qt%{qtmajor} Lib.

%files -n %{libqt5multimediagsttools}
%{_qt5_libdir}/libQt5MultimediaGstTools.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqt5multimediagsttools_d}
Summary:        Devel files needed to build apps based on QtMultimediaGsttools
Group:          Development/KDE and Qt
Requires:       %{libqt5multimediagsttools} = %{version}
Provides:       libqtmultimediagsttools5-devel = %{version}
Provides:       libqt5multimediagsttools-devel = %{version}
Provides:       qtmultimediagsttools5-devel = %{version}
Provides:       qt5multimediagsttools-devel = %{version}

%description -n %{libqt5multimediagsttools_d}
Devel files needed to build apps based on QtMultimediaGsttools.

%files -n %{libqt5multimediagsttools_d}
%{_qt5_includedir}/QtMultimediaGstTools/
%{_qt5_libdir}/libQt5MultimediaGstTools.prl
%{_qt5_libdir}/libQt5MultimediaGstTools.so
%{_qt5_libdir}/cmake/Qt5MultimediaGstTools/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_multimediagsttools_private.pri

#------------------------------------------------------------------------------

%package -n %{libqtmultimediaquick}
Summary:        Qt%{qtmajor} Lib
Group:          System/Libraries
Requires:       %{name} = %{version}

%description -n %{libqtmultimediaquick}
Qt%{qtmajor} Lib.

%files -n %{libqtmultimediaquick}
%{_qt5_libdir}/libQt5MultimediaQuick.so.%{qtmajor}{,.*}

#------------------------------------------------------------------------------

%package -n %{libqtmultimediaquick_d}
Summary:        Devel files needed to build apps based on QtMultimediaQuick
Group:          Development/KDE and Qt
Requires:       %{libqtmultimediaquick} = %{version}
Provides:       libqtmultimediaquick5-devel = %{version}
Provides:       libqt5multimediaquick-devel = %{version}
Provides:       qt5multimediaquick-devel = %{version}
Provides:       qtmultimediaquick5-devel = %{version}

%description -n %{libqtmultimediaquick_d}
Devel files needed to build apps based on QtMultimediaQuick.

%files -n %{libqtmultimediaquick_d}
%{_qt5_libdir}/libQt5MultimediaQuick.prl
%{_qt5_libdir}/libQt5MultimediaQuick.so
%{_qt5_libdir}/cmake/Qt5MultimediaQuick/
%{_qt5_includedir}/QtMultimediaQuick/
%{_qt5_archdatadir}/mkspecs/modules/qt_lib_qtmultimediaquicktools_private.pri

#------------------------------------------------------------------------------

%prep
%setup -q -n qtmultimedia-everywhere-src-%{qtversion}
%autopatch -p1

%build
%qmake_qt5 GST_VERSION=1.0

%make_build

%if %{build_docs}
%__make docs
%endif

%install
%make_install INSTALL_ROOT=%{buildroot}

%if %{build_docs}
%make_install install_docs INSTALL_ROOT=%{buildroot}
%endif

# .la and .a files, die, die, die.
find %{buildroot} -name '*.la' -delete

## .prl/.la file love
# nuke .prl reference(s) to %%buildroot, excessive (.la-like) libs
pushd %{buildroot}%{_qt5_libdir}
for prl_file in libQt5*.prl ; do
  sed -i -e "/^QMAKE_PRL_BUILD_DIR/d" ${prl_file}
  if [ -f "$(basename ${prl_file} .prl).so" ]; then
    rm -fv "$(basename ${prl_file} .prl).la"
    sed -i -e "/^QMAKE_PRL_LIBS/d" ${prl_file}
  fi
done
popd


%changelog
* Sat Jan 18 2025 daviddavid <daviddavid> 5.15.16-1.mga10
+ Revision: 2139620
- New version 5.15.16

* Wed Jan 17 2024 daviddavid <daviddavid> 5.15.12-2.mga10
+ Revision: 2031769
- merge QT/KDE Collection Patches from kde/5.15 branch

* Tue Jan 16 2024 neoclust <neoclust> 5.15.12-1.mga10
+ Revision: 2031612
- New version 5.15.12

* Mon Dec 05 2022 neoclust <neoclust> 5.15.7-1.mga9
+ Revision: 1918198
- New version 5.15.7

* Sat Sep 10 2022 neoclust <neoclust> 5.15.6-1.mga9
+ Revision: 1886279
- New version 5.15.6

* Sat Aug 27 2022 neoclust <neoclust> 5.15.5-1.mga9
+ Revision: 1880953
+ rebuild (emptylog)

* Wed Apr 06 2022 umeabot <umeabot> 5.15.2-3.mga9
+ Revision: 1845587
- Mageia 9 Mass Rebuild

* Mon May 03 2021 daviddavid <daviddavid> 5.15.2-2.mga9
+ Revision: 1721054
- add patch to fix build with gcc 11

* Fri Dec 04 2020 daviddavid <daviddavid> 5.15.2-1.mga8
+ Revision: 1652457
- New version 5.15.2

* Sat Sep 12 2020 daviddavid <daviddavid> 5.15.1-1.mga8
+ Revision: 1624909
- New version 5.15.1

* Wed Jun 03 2020 daviddavid <daviddavid> 5.15.0-1.mga8
+ Revision: 1589822
- New version 5.15.0
+ danf <danf>
- Switch URLs from http: to https:

* Thu Feb 20 2020 umeabot <umeabot> 5.14.1-2.mga8
+ Revision: 1545324
- Mageia 8 Mass Rebuild

* Tue Jan 28 2020 daviddavid <daviddavid> 5.14.1-1.mga8
+ Revision: 1484398
- New version 5.14.1

* Mon Sep 09 2019 neoclust <neoclust> 5.13.1-1.mga8
+ Revision: 1438649
- New version 5.13.1

* Sun Jul 14 2019 neoclust <neoclust> 5.13.0-2.mga8
+ Revision: 1421121
- Rebuild for new mkspecs macros

* Thu Jul 04 2019 daviddavid <daviddavid> 5.13.0-1.mga8
+ Revision: 1418141
- New version 5.13.0

* Mon Apr 01 2019 umeabot <umeabot> 5.12.2-2.mga7
+ Revision: 1384464
- Qt5 Rebuild

* Mon Mar 18 2019 neoclust <neoclust> 5.12.2-1.mga7
+ Revision: 1378537
- New version 5.12.2

* Fri Feb 01 2019 neoclust <neoclust> 5.12.1-1.mga7
+ Revision: 1362282
- New version 5.12.1

* Sun Dec 09 2018 neoclust <neoclust> 5.12.0-1.mga7
+ Revision: 1339137
- New version 5.12.0

* Tue Oct 09 2018 neoclust <neoclust> 5.11.2-1.mga7
+ Revision: 1319026
- New version 5.11.2

* Sun Sep 23 2018 umeabot <umeabot> 5.11.1-2.mga7
+ Revision: 1300712
- Mageia 7 Mass Rebuild

* Sun Jul 29 2018 neoclust <neoclust> 5.11.1-1.mga7
+ Revision: 1245813
- New version 5.11.1

* Fri May 25 2018 neoclust <neoclust> 5.11.0-1.mga7
+ Revision: 1232112
- New version 5.11.0

* Thu Apr 12 2018 neoclust <neoclust> 5.10.1-2.mga7
+ Revision: 1217994
- New version 5.10.1

* Wed Feb 28 2018 neoclust <neoclust> 5.9.4-1.mga7
+ Revision: 1205679
- New version 5.9.4

* Wed Jan 03 2018 neoclust <neoclust> 5.9.3-2.mga7
+ Revision: 1190050
- Pull main package by the libs

* Mon Dec 18 2017 neoclust <neoclust> 5.9.3-1.mga7
+ Revision: 1183184
- New version 5.9.3

* Sun Jul 16 2017 neoclust <neoclust> 5.9.1-1.mga7
+ Revision: 1123571
- New version 5.9.1

* Wed Mar 01 2017 ghibo <ghibo> 5.6.2-2.mga6
+ Revision: 1088332
- Rebuilt against pulseaudio 10

* Thu Nov 03 2016 neoclust <neoclust> 5.6.2-1.mga6
+ Revision: 1064861
- New version 5.6.2

* Sun Oct 16 2016 wally <wally> 5.6.1-4.mga6
+ Revision: 1061133
- fix lib and devel pkg names

* Fri Sep 02 2016 daviddavid <daviddavid> 5.6.1-3.mga6
+ Revision: 1049784
- build missing docs part (mga#9812)
- add qtmultimedia5-doc subpackage

* Sun Jul 03 2016 neoclust <neoclust> 5.6.1-2.mga6
+ Revision: 1038376
- Update to version 5.6.1-1
- New version

* Sat Apr 23 2016 daviddavid <daviddavid> 5.6.0-4.mga6
+ Revision: 1005447
- explicitly set the gstreamer support version who should be used (fixes mga#18229)

* Sat Apr 23 2016 neoclust <neoclust> 5.6.0-3.mga6
+ Revision: 1005399
- Enhance gst buildrequires

* Sat Apr 23 2016 neoclust <neoclust> 5.6.0-2.mga6
+ Revision: 1005396
- Explicit file list

* Thu Mar 17 2016 neoclust <neoclust> 5.6.0-1.mga6
+ Revision: 992493
- Fix release tag

* Wed Mar 09 2016 neoclust <neoclust> 5.6.0-0.rc.2.mga6
+ Revision: 987981
- Rebuild Qt5 Stack to fix plasma crashes

* Sun Feb 28 2016 neoclust <neoclust> 5.6.0-0.rc.1.mga6
+ Revision: 980612
- New version 5.6.0 rc

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.4.mga6
+ Revision: 915946
- Rebuild against new cmake to have cmake() provides

* Sun Dec 27 2015 neoclust <neoclust> 5.6.0-0.beta.3.mga6
+ Revision: 915810
- Rebuild against new cmake to have cmake() provides

* Sun Dec 20 2015 neoclust <neoclust> 5.6.0-0.beta.2.mga6
+ Revision: 912734
- Remove private devel packages

* Sat Dec 19 2015 neoclust <neoclust> 5.6.0-0.beta.1.mga6
+ Revision: 912299
- New version 5.6.0 Beta

* Tue Nov 10 2015 neoclust <neoclust> 5.5.1-3.mga6
+ Revision: 900848
- Rebuild against fixed qtbase5
- Use GStreamer 1.0

* Fri Oct 23 2015 neoclust <neoclust> 5.5.1-1.mga6
+ Revision: 894499
- New version

* Sat Jul 25 2015 neoclust <neoclust> 5.5.0-2.mga6
+ Revision: 857079
- Fix Requires

* Sun Jul 12 2015 filipesaraiva <filipesaraiva> 5.5.0-1.mga6
+ Revision: 853382
- Update to Qt 5.5.0 version;
- Fix URL to new address qt.io;

* Tue Jun 23 2015 neoclust <neoclust> 5.5.0-0.rc.1.mga6
+ Revision: 840313
- New version 5.5 rc

* Fri Dec 12 2014 neoclust <neoclust> 5.4.0-1.mga5
+ Revision: 802853
- New version 5.4.0

* Sun Dec 07 2014 neoclust <neoclust> 5.3.2-1.mga5
+ Revision: 801809
- New version 5.3.2

* Wed Oct 15 2014 umeabot <umeabot> 5.3.1-3.mga5
+ Revision: 745029
- Second Mageia 5 Mass Rebuild

* Sun Oct 12 2014 umeabot <umeabot> 5.3.1-2.mga5
+ Revision: 738093
- Mageia 5 Mass Rebuild

* Thu Jun 26 2014 fwang <fwang> 5.3.1-1.mga5
+ Revision: 639783
- 5.3.1

* Tue May 20 2014 fwang <fwang> 5.3.0-1.mga5
+ Revision: 624083
- 5.3.0 final

* Fri May 09 2014 fwang <fwang> 5.3.0-0.rc.1.mga5
+ Revision: 621471
- 5.3.0rc

* Sun Apr 06 2014 fwang <fwang> 5.3.0-0.beta.1.mga5
+ Revision: 612317
- 5.3.0beta

* Mon Mar 03 2014 neoclust <neoclust> 5.3.0-0.alpha.1.mga5
+ Revision: 598936
- New version

* Thu Feb 06 2014 fwang <fwang> 5.2.1-1.mga5
+ Revision: 584239
- 5.2.1

* Sat Dec 14 2013 fwang <fwang> 5.2.0-2.mga4
+ Revision: 556712
- 5.2.0 final

* Sun Dec 01 2013 fwang <fwang> 5.2.0-1.rc1.1.mga4
+ Revision: 554450
- update file list
- 5.2.0 rc1

* Sat Oct 26 2013 fwang <fwang> 5.2.0-1.beta1.1.mga4
+ Revision: 547099
- 5.2.0 beta1
+ umeabot <umeabot>
- Mageia 4 Mass Rebuild

* Fri Oct 04 2013 fwang <fwang> 5.2.0-1.alpha.1.mga4
+ Revision: 491151
- 5.2.0 alpha1

* Mon May 27 2013 neoclust <neoclust> 5.2.0-0.0.20130523.2.mga4
+ Revision: 428821
- Rebuild against new qt5 libs location

* Sun May 26 2013 neoclust <neoclust> 5.2.0-0.0.20130523.1.mga4
+ Revision: 428123
- New QT 5.2 Snapshot

* Wed Apr 17 2013 neoclust <neoclust> 5.0.2-1.mga3
+ Revision: 410282
- New version 5.0.2

* Fri Feb 01 2013 neoclust <neoclust> 5.0.1-1.mga3
+ Revision: 393966
- New version 5.0.1 Final

* Sat Jan 26 2013 neoclust <neoclust> 5.0.1-0.rc1.1.mga3
+ Revision: 392357
- New version 5.0.1 rc1

* Fri Jan 25 2013 neoclust <neoclust> 5.0.0-1.mga3
+ Revision: 392295
- imported package qtmultimedia5

